.. fluxfootprint documentation master file, created by
   sphinx-quickstart on Fri May  2 07:30:12 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

fluxfootprint documentation
===========================


.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   fluxfootprints
   modules
   exp
   modeltypes
   Quick-start notebook <notebooks/test.ipynb>

